@@ -305,22 +305,23 @@ class trains_data_loader:
         self.test_X = pd.DataFrame()
         self.test_y = pd.DataFrame()
 
-        # trains_start_year = trains_start[0:4]
-        # trains_end_year = trains_end[0:4]
-        # test_start_year = test_start[0:4]
-        # test_end_year = test_end[0:4]
         file_list = os.listdir(self.module_path + self.feature_dir)
         for index, file in enumerate(file_list):
             print(f"读取进度:{(index / len(file_list)) * 100}")
             data = pd.read_csv(self.module_path + self.feature_dir + file, encoding='utf-8')
-
+            if len(data)==0:
+                continue
             trains_x = data[(data['trade_date'] > trains_start) & (data['trade_date'] < trains_end)]
+            if len(trains_x) ==0:
+                continue
             trains_y = trains_x['flag']
             trains_x = trains_x.drop(self.drop_column, axis=1)
             self.train_X = pd.concat([self.train_X, trains_x])
             self.train_y = pd.concat([self.train_y, trains_y])
 
             test_X = data[(data['trade_date'] > test_start) & (data['trade_date'] < test_end)]
+            if len(test_X) ==0:
+                continue
             test_y = test_X['flag']
             test_X = test_X.drop(self.drop_column, axis=1)
             self.test_X = pd.concat([self.test_X, test_X])
